@@ -1,6 +1,6 @@
 /** \file mod_info.h       General information functions
  *
- *             Part of MODELLER, Copyright(c) 1989-2020 Andrej Sali
+ *             Part of MODELLER, Copyright(c) 1989-2021 Andrej Sali
  */
 
 #ifndef MOD_INFO_H
@@ -13,6 +13,10 @@ extern "C" {
 /** Get the current date and time */
 char *mod_current_time_get(void);
 
+/** Get deprecation mode ("ERROR", "WARN" or "", from the
+    MODELLER_DEPRECATION environment variable */
+char *mod_deprecation_mode_get(void);
+
 /** Print wall and CPU time since this routine was last called */
 void mod_time_mark(void);
 
